@@ -2,20 +2,22 @@
 # Licensed according to the LICENCE file on the master branch
 """Utilities for handling data."""
 from __future__ import annotations
+
+import datetime
+import json
 import os
 import sys
-import json
-from typing import Union
-from collections import OrderedDict
 from collections.abc import Iterable
-import datetime
-from uuid import uuid4
 from pathlib import Path
-from dateutil.parser import parse
+from typing import Union
+from uuid import uuid4
 
 import numpy as np
 import xarray as xr
+from dateutil.parser import parse
 from qcodes import Instrument
+
+import quantify_core.data.dataset_adapters as da
 from quantify_core.data.types import TUID
 from quantify_core.utilities.general import delete_keys_from_dict
 
@@ -57,7 +59,8 @@ def gen_tuid(time_stamp: datetime.datetime = None) -> TUID:
 def get_datadir() -> str:
     """
     Returns the current data directory.
-    The data directory can be changed using :func:`~quantify_core.data.handling.set_datadir`.
+    The data directory can be changed using
+    :func:`~quantify_core.data.handling.set_datadir`.
 
     Returns
     -------
@@ -102,8 +105,8 @@ def locate_experiment_container(tuid: TUID, datadir: str = None) -> str:
     Parameters
     ----------
     tuid
-        A :class:`~quantify_core.data.types.TUID` string. It is also possible to specify only
-        the first part of a tuid.
+        A :class:`~quantify_core.data.types.TUID` string. It is also possible to specify
+        only the first part of a tuid.
     datadir
         Path of the data directory. If ``None``, uses :meth:`~get_datadir` to determine
         the data directory.
@@ -159,8 +162,8 @@ def load_dataset(
     Parameters
     ----------
     tuid
-        A :class:`~quantify_core.data.types.TUID` string. It is also possible to specify only
-        the first part of a tuid.
+        A :class:`~quantify_core.data.types.TUID` string. It is also possible to specify
+        only the first part of a tuid.
     datadir
         Path of the data directory. If ``None``, uses :meth:`~get_datadir` to determine
         the data directory.
@@ -180,6 +183,10 @@ def load_dataset_from_path(path: Union[Path, str]) -> xr.Dataset:
     """
     Loads a :class:`~xarray.Dataset` with a specific engine preference.
 
+    Before returning the dataset
+    :meth:`AdapterH5NetCDF.recover() <quantify_core.data.dataset_adapters.AdapterH5NetCDF.recover>`
+    is applied.
+
     This function tries to load the dataset until success with the following engine
     preference:
 
@@ -196,7 +203,7 @@ def load_dataset_from_path(path: Union[Path, str]) -> xr.Dataset:
     -------
     :
         The loaded dataset.
-    """
+    """  # pylint: disable=line-too-long
     exceptions = []
     engines = ["h5netcdf", "netcdf4", None]
     for engine in engines:
@@ -205,6 +212,9 @@ def load_dataset_from_path(path: Union[Path, str]) -> xr.Dataset:
         except Exception as exception:
             exceptions.append(exception)
         else:
+            # Only quantify_dataset_version=>2.0.0 requires the adapter
+            if "quantify_dataset_version" in dataset.attrs:
+                dataset = da.AdapterH5NetCDF.recover(dataset)
             return dataset
 
     # Do not let exceptions pass silently
@@ -315,6 +325,10 @@ def write_dataset(path: Union[Path, str], dataset: xr.Dataset) -> None:
     """
     Writes a :class:`~xarray.Dataset` to a file with the `h5netcdf` engine.
 
+    Before writing the
+    :meth:`AdapterH5NetCDF.adapt() <quantify_core.data.dataset_adapters.AdapterH5NetCDF.adapt>`
+    is applied.
+
     To accommodate for complex-type numbers and arrays ``invalid_netcdf=True`` is used.
 
     Parameters
@@ -323,8 +337,11 @@ def write_dataset(path: Union[Path, str], dataset: xr.Dataset) -> None:
         Path to the file including filename and extension
     dataset
         The :class:`~xarray.Dataset` to be written to file.
-    """
+    """  # pylint: disable=line-too-long
     _xarray_numpy_bool_patch(dataset)  # See issue #161 in quantify-core
+    # Only quantify_dataset_version=>2.0.0 requires the adapter
+    if "quantify_dataset_version" in dataset.attrs:
+        dataset = da.AdapterH5NetCDF.adapt(dataset)
     dataset.to_netcdf(path, engine="h5netcdf", invalid_netcdf=True)
 
 
@@ -335,8 +352,8 @@ def load_snapshot(tuid: TUID, datadir: str = None, file: str = "snapshot.json")
     Parameters
     ----------
     tuid
-        A :class:`~quantify_core.data.types.TUID` string. It is also possible to specify only
-        the first part of a tuid.
+        A :class:`~quantify_core.data.types.TUID` string. It is also possible to specify
+        only the first part of a tuid.
     datadir
         Path of the data directory. If ``None``, uses :meth:`~get_datadir` to determine
         the data directory.
@@ -460,7 +477,7 @@ def initialize_dataset(
     dataset = xr.merge(darrs)
     dataset = dataset.set_coords(coords)
     # xarray>=0.18.0 tries to combine attrs which we do not want at all
-    dataset.attrs = dict()
+    dataset.attrs = {}
     dataset.attrs["tuid"] = gen_tuid()
     return dataset
 
@@ -493,7 +510,7 @@ def grow_dataset(dataset: xr.Dataset) -> xr.Dataset:
     coords = tuple(dataset.coords.keys())
     dataset = dataset.drop_dims(["dim_0"])
     merged_data_arrays = xr.merge(darrs)
-    merged_data_arrays.attrs = dict()  # xarray>=0.18.0 tries to merge attrs
+    merged_data_arrays.attrs = {}  # xarray>=0.18.0 tries to merge attrs
     dataset = dataset.merge(merged_data_arrays)
     dataset = dataset.set_coords(coords)
     return dataset
@@ -528,7 +545,7 @@ def trim_dataset(dataset: xr.Dataset) -> xr.Dataset:
                 )
             dataset = dataset.drop_dims(["dim_0"])
             merged_data_arrays = xr.merge(darrs)
-            merged_data_arrays.attrs = dict()  # xarray>=0.18.0 tries to merge attrs
+            merged_data_arrays.attrs = {}  # xarray>=0.18.0 tries to merge attrs
             dataset = dataset.merge(merged_data_arrays)
             dataset = dataset.set_coords(coords)
             break
@@ -561,7 +578,7 @@ def to_gridded_dataset(
     - The :code:`y0, y1, ...` Variables are reshaped into a (multi-)dimensional grid
         and associated to the Coordinates.
 
-    .. seealso:: :meth:`~quantify_core.measurement.MeasurementControl.setpoints_grid`
+    .. seealso:: :meth:`.MeasurementControl.setpoints_grid`
 
     Parameters
     ----------
@@ -580,14 +597,23 @@ def to_gridded_dataset(
         The new dataset.
 
 
-    .. include:: ./docstring_examples/quantify_core.data.handling.to_gridded_dataset.rst.txt
+    .. include:: examples/data.handling.to_gridded_dataset.py.rst.txt
     """
+    if dimension not in quantify_dataset.dims:
+        dims = tuple(quantify_dataset.dims.keys())
+        raise ValueError(f"Dimension {dimension} not in dims {dims}.")
 
     if coords_names is None:
         # for compatibility with older datasets we use `variables` instead of `coords`
         coords_names = sorted(
             v for v in quantify_dataset.variables.keys() if v.startswith("x")
         )
+    else:
+        for coord in coords_names:
+            vars_ = tuple(quantify_dataset.variables.keys())
+            if coord not in vars_:
+                raise ValueError(f"Coordinate {coord} not in coordinates {vars_}.")
+
     # Because xarray in general creates new objects and
     # due to https://github.com/pydata/xarray/issues/2245
     # the attributes need to be saved and restored in the new object
@@ -625,8 +651,8 @@ def get_latest_tuid(contains: str = "") -> TUID:
     .. tip::
 
         This function is similar to :func:`~get_tuids_containing` but is preferred if
-        one is only interested in the most recent :class:`~quantify_core.data.types.TUID`
-        for performance reasons.
+        one is only interested in the most recent
+        :class:`~quantify_core.data.types.TUID` for performance reasons.
 
     Parameters
     ----------
@@ -658,8 +684,9 @@ def get_tuids_containing(
 
     .. tip::
 
-        If one is only interested in the most recent :class:`~quantify_core.data.types.TUID`,
-        :func:`~get_latest_tuid` is preferred for performance reasons.
+        If one is only interested in the most recent
+        :class:`~quantify_core.data.types.TUID`, :func:`~get_latest_tuid` is preferred
+        for performance reasons.
 
     Parameters
     ----------
@@ -751,7 +778,7 @@ def get_tuids_containing(
     return tuids
 
 
-def snapshot(update: bool = False, clean: bool = True) -> OrderedDict:
+def snapshot(update: bool = False, clean: bool = True) -> dict:
     """
     State of all instruments setup as a JSON-compatible dictionary (everything that the
     custom JSON encoder class :class:`qcodes.utils.helpers.NumpyJSONEncoder` supports).
@@ -765,14 +792,12 @@ def snapshot(update: bool = False, clean: bool = True) -> OrderedDict:
         compact snapshot.
     """
 
-    snap = OrderedDict(
-        {
-            "instruments": {},
-            "parameters": {},
-        }
-    )
+    snap = {"instruments": {}, "parameters": {}}
     for ins_name, ins_ref in Instrument._all_instruments.items():
-        snap["instruments"][ins_name] = ins_ref().snapshot(update=update)
+        ref = ins_ref()
+        # Check for dead weakrefs
+        if ref is not None:
+            snap["instruments"][ins_name] = ref.snapshot(update=update)
 
     if clean:
         exclude_keys = {
@@ -780,7 +805,6 @@ def snapshot(update: bool = False, clean: bool = True) -> OrderedDict:
             "post_delay",
             "vals",
             "instrument",
-            "submodules",
             "functions",
             "__class__",
             "raw_value",
